pub enum Event {
Key(KeyEvent),
Mouse(MouseEvent),
WindowResized(WindowSize),
FocusIn,
FocusOut,
Paste(String),
Csi(Csi),
Osc(Osc<'static>),
Dcs(Dcs),
}Variants
Key(KeyEvent)
Mouse(MouseEvent)
WindowResized(WindowSize)
The window was resized to the given dimensions.
FocusIn
FocusOut
Paste(String)
A “bracketed” paste.
Normally pasting into a terminal with Ctrl+v (or Super+v) enters the pasted text as if you had typed the keys individually. Terminals commonly support “bracketed paste” now however, which uses an escape sequence to deliver the entire pasted content.
Csi(Csi)
A parsed escape sequence starting with CSI (control sequence introducer).
Osc(Osc<'static>)
A parsed escape sequence starting with OSC (operating system command).
Dcs(Dcs)
Implementations